==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/RuntimeQueue.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A Queue.
 */
@ResourceType("runtime-queue")
public class RuntimeQueue<T extends RuntimeQueue> {

	private String key;
	private Integer consumerCount;
	private String deadLetterAddress;
	private Integer deliveringCount;
	private Boolean durable;
	private String expiryAddress;
	private String filter;
	private Long id;
	private Long messageCount;
	private Long messagesAdded;
	private Boolean paused;
	private String queueAddress;
	private Long scheduledCount;
	private Boolean temporary;

	public RuntimeQueue(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The number of consumers consuming messages from this queue.
	 */
	@ModelNodeBinding(detypedName = "consumer-count")
	public Integer consumerCount() {
		return this.consumerCount;
	}

	/**
	 * The number of consumers consuming messages from this queue.
	 */
	@SuppressWarnings("unchecked")
	public T consumerCount(Integer value) {
		this.consumerCount = value;
		return (T) this;
	}

	/**
	 * The address to send the queue's dead messages to.
	 */
	@ModelNodeBinding(detypedName = "dead-letter-address")
	public String deadLetterAddress() {
		return this.deadLetterAddress;
	}

	/**
	 * The address to send the queue's dead messages to.
	 */
	@SuppressWarnings("unchecked")
	public T deadLetterAddress(String value) {
		this.deadLetterAddress = value;
		return (T) this;
	}

	/**
	 * The number of messages that this queue is currently delivering to its consumers.
	 */
	@ModelNodeBinding(detypedName = "delivering-count")
	public Integer deliveringCount() {
		return this.deliveringCount;
	}

	/**
	 * The number of messages that this queue is currently delivering to its consumers.
	 */
	@SuppressWarnings("unchecked")
	public T deliveringCount(Integer value) {
		this.deliveringCount = value;
		return (T) this;
	}

	/**
	 * Defines whether the queue is durable.
	 */
	@ModelNodeBinding(detypedName = "durable")
	public Boolean durable() {
		return this.durable;
	}

	/**
	 * Defines whether the queue is durable.
	 */
	@SuppressWarnings("unchecked")
	public T durable(Boolean value) {
		this.durable = value;
		return (T) this;
	}

	/**
	 * The address to send the queue's expired messages to.
	 */
	@ModelNodeBinding(detypedName = "expiry-address")
	public String expiryAddress() {
		return this.expiryAddress;
	}

	/**
	 * The address to send the queue's expired messages to.
	 */
	@SuppressWarnings("unchecked")
	public T expiryAddress(String value) {
		this.expiryAddress = value;
		return (T) this;
	}

	/**
	 * A queue message filter definition. An undefined or empty filter will match all messages.
	 */
	@ModelNodeBinding(detypedName = "filter")
	public String filter() {
		return this.filter;
	}

	/**
	 * A queue message filter definition. An undefined or empty filter will match all messages.
	 */
	@SuppressWarnings("unchecked")
	public T filter(String value) {
		this.filter = value;
		return (T) this;
	}

	/**
	 * The id of the queue.
	 */
	@ModelNodeBinding(detypedName = "id")
	public Long id() {
		return this.id;
	}

	/**
	 * The id of the queue.
	 */
	@SuppressWarnings("unchecked")
	public T id(Long value) {
		this.id = value;
		return (T) this;
	}

	/**
	 * The number of messages currently in this queue.
	 */
	@ModelNodeBinding(detypedName = "message-count")
	public Long messageCount() {
		return this.messageCount;
	}

	/**
	 * The number of messages currently in this queue.
	 */
	@SuppressWarnings("unchecked")
	public T messageCount(Long value) {
		this.messageCount = value;
		return (T) this;
	}

	/**
	 * The number of messages added to this queue since it was created.
	 */
	@ModelNodeBinding(detypedName = "messages-added")
	public Long messagesAdded() {
		return this.messagesAdded;
	}

	/**
	 * The number of messages added to this queue since it was created.
	 */
	@SuppressWarnings("unchecked")
	public T messagesAdded(Long value) {
		this.messagesAdded = value;
		return (T) this;
	}

	/**
	 * Whether the queue is paused.
	 */
	@ModelNodeBinding(detypedName = "paused")
	public Boolean paused() {
		return this.paused;
	}

	/**
	 * Whether the queue is paused.
	 */
	@SuppressWarnings("unchecked")
	public T paused(Boolean value) {
		this.paused = value;
		return (T) this;
	}

	/**
	 * The queue address defines what address is used for routing messages.
	 */
	@ModelNodeBinding(detypedName = "queue-address")
	public String queueAddress() {
		return this.queueAddress;
	}

	/**
	 * The queue address defines what address is used for routing messages.
	 */
	@SuppressWarnings("unchecked")
	public T queueAddress(String value) {
		this.queueAddress = value;
		return (T) this;
	}

	/**
	 * The number of scheduled messages in this queue.
	 */
	@ModelNodeBinding(detypedName = "scheduled-count")
	public Long scheduledCount() {
		return this.scheduledCount;
	}

	/**
	 * The number of scheduled messages in this queue.
	 */
	@SuppressWarnings("unchecked")
	public T scheduledCount(Long value) {
		this.scheduledCount = value;
		return (T) this;
	}

	/**
	 * Whether the queue is temporary.
	 */
	@ModelNodeBinding(detypedName = "temporary")
	public Boolean temporary() {
		return this.temporary;
	}

	/**
	 * Whether the queue is temporary.
	 */
	@SuppressWarnings("unchecked")
	public T temporary(Boolean value) {
		this.temporary = value;
		return (T) this;
	}
}

==> config-api-0.3.15-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/RuntimeQueue.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Address;
import org.wildfly.swarm.config.runtime.ResourceType;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A Queue.
 */
@Address("/subsystem=messaging-activemq/server=*/runtime-queue=*")
@ResourceType("runtime-queue")
public class RuntimeQueue<T extends RuntimeQueue<T>> {

	private String key;
	private PropertyChangeSupport pcs;
	private Integer consumerCount;
	private String deadLetterAddress;
	private Integer deliveringCount;
	private Boolean durable;
	private String expiryAddress;
	private String filter;
	private Long id;
	private Long messageCount;
	private Long messagesAdded;
	private Boolean paused;
	private String queueAddress;
	private Long scheduledCount;
	private Boolean temporary;

	public RuntimeQueue(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The number of consumers consuming messages from this queue.
	 */
	@ModelNodeBinding(detypedName = "consumer-count")
	public Integer consumerCount() {
		return this.consumerCount;
	}

	/**
	 * The number of consumers consuming messages from this queue.
	 */
	@SuppressWarnings("unchecked")
	public T consumerCount(Integer value) {
		Object oldValue = this.consumerCount;
		this.consumerCount = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("consumerCount", oldValue, value);
		return (T) this;
	}

	/**
	 * The address to send the queue's dead messages to.
	 */
	@ModelNodeBinding(detypedName = "dead-letter-address")
	public String deadLetterAddress() {
		return this.deadLetterAddress;
	}

	/**
	 * The address to send the queue's dead messages to.
	 */
	@SuppressWarnings("unchecked")
	public T deadLetterAddress(String value) {
		Object oldValue = this.deadLetterAddress;
		this.deadLetterAddress = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("deadLetterAddress", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of messages that this queue is currently delivering to its
	 * consumers.
	 */
	@ModelNodeBinding(detypedName = "delivering-count")
	public Integer deliveringCount() {
		return this.deliveringCount;
	}

	/**
	 * The number of messages that this queue is currently delivering to its
	 * consumers.
	 */
	@SuppressWarnings("unchecked")
	public T deliveringCount(Integer value) {
		Object oldValue = this.deliveringCount;
		this.deliveringCount = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("deliveringCount", oldValue, value);
		return (T) this;
	}

	/**
	 * Defines whether the queue is durable.
	 */
	@ModelNodeBinding(detypedName = "durable")
	public Boolean durable() {
		return this.durable;
	}

	/**
	 * Defines whether the queue is durable.
	 */
	@SuppressWarnings("unchecked")
	public T durable(Boolean value) {
		Object oldValue = this.durable;
		this.durable = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("durable", oldValue, value);
		return (T) this;
	}

	/**
	 * The address to send the queue's expired messages to.
	 */
	@ModelNodeBinding(detypedName = "expiry-address")
	public String expiryAddress() {
		return this.expiryAddress;
	}

	/**
	 * The address to send the queue's expired messages to.
	 */
	@SuppressWarnings("unchecked")
	public T expiryAddress(String value) {
		Object oldValue = this.expiryAddress;
		this.expiryAddress = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("expiryAddress", oldValue, value);
		return (T) this;
	}

	/**
	 * A queue message filter definition. An undefined or empty filter will
	 * match all messages.
	 */
	@ModelNodeBinding(detypedName = "filter")
	public String filter() {
		return this.filter;
	}

	/**
	 * A queue message filter definition. An undefined or empty filter will
	 * match all messages.
	 */
	@SuppressWarnings("unchecked")
	public T filter(String value) {
		Object oldValue = this.filter;
		this.filter = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("filter", oldValue, value);
		return (T) this;
	}

	/**
	 * The id of the queue.
	 */
	@ModelNodeBinding(detypedName = "id")
	public Long id() {
		return this.id;
	}

	/**
	 * The id of the queue.
	 */
	@SuppressWarnings("unchecked")
	public T id(Long value) {
		Object oldValue = this.id;
		this.id = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("id", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of messages currently in this queue.
	 */
	@ModelNodeBinding(detypedName = "message-count")
	public Long messageCount() {
		return this.messageCount;
	}

	/**
	 * The number of messages currently in this queue.
	 */
	@SuppressWarnings("unchecked")
	public T messageCount(Long value) {
		Object oldValue = this.messageCount;
		this.messageCount = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("messageCount", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of messages added to this queue since it was created.
	 */
	@ModelNodeBinding(detypedName = "messages-added")
	public Long messagesAdded() {
		return this.messagesAdded;
	}

	/**
	 * The number of messages added to this queue since it was created.
	 */
	@SuppressWarnings("unchecked")
	public T messagesAdded(Long value) {
		Object oldValue = this.messagesAdded;
		this.messagesAdded = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("messagesAdded", oldValue, value);
		return (T) this;
	}

	/**
	 * Whether the queue is paused.
	 */
	@ModelNodeBinding(detypedName = "paused")
	public Boolean paused() {
		return this.paused;
	}

	/**
	 * Whether the queue is paused.
	 */
	@SuppressWarnings("unchecked")
	public T paused(Boolean value) {
		Object oldValue = this.paused;
		this.paused = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("paused", oldValue, value);
		return (T) this;
	}

	/**
	 * The queue address defines what address is used for routing messages.
	 */
	@ModelNodeBinding(detypedName = "queue-address")
	public String queueAddress() {
		return this.queueAddress;
	}

	/**
	 * The queue address defines what address is used for routing messages.
	 */
	@SuppressWarnings("unchecked")
	public T queueAddress(String value) {
		Object oldValue = this.queueAddress;
		this.queueAddress = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("queueAddress", oldValue, value);
		return (T) this;
	}

	/**
	 * The number of scheduled messages in this queue.
	 */
	@ModelNodeBinding(detypedName = "scheduled-count")
	public Long scheduledCount() {
		return this.scheduledCount;
	}

	/**
	 * The number of scheduled messages in this queue.
	 */
	@SuppressWarnings("unchecked")
	public T scheduledCount(Long value) {
		Object oldValue = this.scheduledCount;
		this.scheduledCount = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("scheduledCount", oldValue, value);
		return (T) this;
	}

	/**
	 * Whether the queue is temporary.
	 */
	@ModelNodeBinding(detypedName = "temporary")
	public Boolean temporary() {
		return this.temporary;
	}

	/**
	 * Whether the queue is temporary.
	 */
	@SuppressWarnings("unchecked")
	public T temporary(Boolean value) {
		Object oldValue = this.temporary;
		this.temporary = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("temporary", oldValue, value);
		return (T) this;
	}
}
